import { CleanEnv, CleanOptions, ValidatorSpec } from './types';
/**
 * Returns a sanitized, immutable environment object. _Only_ the env vars
 * specified in the `validators` parameter will be accessible on the returned
 * object.
 * @param environment An object containing your env vars (eg. process.env).
 * @param specs An object that specifies the format of required vars.
 * @param options An object that specifies options for cleanEnv.
 */
declare function cleanEnv<T>(environment: unknown, specs: {
    [K in keyof T]: ValidatorSpec<T[K]>;
}, options?: CleanOptions<T>): Readonly<T> & CleanEnv;
/**
 * Utility function for providing default values only when NODE_ENV=test
 *
 * For more context, see https://github.com/af/envalid/issues/32
 */
declare const testOnly: (defaultValueForTests: any) => any;
export { cleanEnv, testOnly };
